RespondPermissionTool

Struct RespondPermissionTool 

pub struct RespondPermissionTool { /* private fields */ }
Tool for responding to permission requests from OpenCode sessions.

After sending the reply, continues monitoring the session and returns when the session completes or another permission is requested.

Implementations

Source

impl RespondPermissionTool

pub fn new(server: Arc<OnceCell<OrchestratorServer>>) -> Self

Create a new RespondPermissionTool with the given server cell.