Module version

Module version 

Structs

LauncherConfig
Configuration for launching the OpenCode server.

Constants

OPENCODE_BINARY_ARGS_ENV
Environment variable for extra arguments between binary and serve command.
OPENCODE_BINARY_ENV
Environment variable for the opencode binary path.
PINNED_OPENCODE_VERSION
Pinned opencode server version for SDK compatibility testing.

Functions

default_pinned_binary_path
parse_launcher_args
Parse launcher args from OPENCODE_BINARY_ARGS environment variable.
resolve_launcher_config
Resolve the full launcher configuration for starting OpenCode.
resolve_opencode_binary
validate_exact_version
Validate that the actual version matches the pinned version exactly.