parse_launcher_args

Function parse_launcher_args 

pub fn parse_launcher_args() -> Vec<String>
Parse launcher args from OPENCODE_BINARY_ARGS environment variable.

Splits on whitespace. Returns empty Vec if unset or empty.

Note: This uses simple whitespace splitting and does not support shell-style quoting. Arguments containing spaces (e.g., --message "hello world") will be incorrectly split. This is acceptable for the documented use case (--yes opencode-ai@1.3.17).