validate_exact_version

Function validate_exact_version 

pub fn validate_exact_version(actual: Option<&str>) -> Result<(), OpencodeError>
Validate that the actual version matches the pinned version exactly.

Errors

Returns an error if the version is missing or doesn’t match.