pub struct RespondPermissionTool { /* private fields */ }Expand description
Tool for responding to permission requests from OpenCode sessions.
After sending the reply, continues monitoring the session and returns when the session completes or another permission is requested.
Implementations
Sourceimpl RespondPermissionTool
impl RespondPermissionTool
Sourcepub fn new(server: Arc<OnceCell<OrchestratorServer>>) -> Self
pub fn new(server: Arc<OnceCell<OrchestratorServer>>) -> Self
Create a new RespondPermissionTool with the given server cell.